@@ -30,17 +30,20 @@ OPTIONS:
     -t --taxonomy=PATH  The path of a TSV file mapping labels onto taxa. If not
                         specified, use the "taxonomy.tsv" present in DIRECTORY's
                         parent. If absent, use the included default taxonomy:
-                        https://github.com/laowantong/paroxython/blob/0.5.3/paroxython/resources/taxonomy.tsv
+                        https://github.com/laowantong/paroxython/blob/0.6.0/paroxython/resources/taxonomy.tsv
     ```
 """
 
 from pathlib import Path
 
+from .goodies import print_exit
 from .make_db import TagDatabase
 
 
 def cli_wrapper(args):
     directory = Path(args["DIRECTORY"])
+    if not directory.is_dir():
+        print_exit(f"no directory at '{directory.absolute()}': aborted.")
     taxonomy = args.get("--taxonomy")
     if taxonomy:
         taxonomy_path = Path(taxonomy)
